pub fn bessel_yv_impl<P, E, V, const A1: usize, const A2: usize, const A3: usize, const AH: usize, const B1: usize, const B2: usize, const B3: usize, const BH: usize, const J1: usize, const J2: usize, const JH: usize, const K1: usize, const K2: usize, const KH: usize>(
x: V,
n: V,
t0: &BesselY<E, A1, A2, A3, AH>,
t1: &BesselY<E, B1, B2, B3, BH>,
tj0: &BesselJ<E, J1, J2, JH>,
tj1: &BesselJ<E, K1, K2, KH>,
) -> VExpand description
Y_n(x) with a per-lane order.
Upward recurrence with each lane freezing at its own order, the hermitev shape. Y is
the dominant solution so there is only ever one arm, which makes this the simplest of the
four runtime-order entry points.